#
# spec file for package diskimage-builder
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Prevent shebangs of element scripts from being added as a requirement (they
# are only ever run inside the disk image build chroot).
%global         __requires_exclude_from ^%{_datadir}/%{name}/elements/.*$
Name:           diskimage-builder
Version:        1.26.1
Release:        1.2
Summary:        Image Building Tools for OpenStack
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/openstack/diskimage-builder
Source0:        https://pypi.io/packages/source/d/%{name}/%{name}-%{version}.tar.gz
Source99:       diskimage-builder-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  python-PyYAML
BuildRequires:  python-devel
# Test requirements:
BuildRequires:  python-fixtures
BuildRequires:  python-oslotest
BuildRequires:  python-pbr >= 0.5.10
BuildRequires:  python-setuptools
BuildRequires:  python-testrepository
BuildRequires:  python-testtools
# No stuff in python_sitelib, thus autoreqprov won't work:
Requires:       python-Babel >= 2.3.4
Requires:       python-PyYAML >= 3.1.0
Requires:       python-dib-utils
Requires:       python-six >= 1.9.0
Requires:       qemu-tools
Requires:       python(abi) = %{py_ver}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
These tools are the components of TripleO
(https://wiki.openstack.org/wiki/TripleO) that are responsible for
building disk images.

%prep
%setup -q

%build
%{__python2} setup.py build

%install
%{__python2} setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes %{buildroot}

%check
if [ ! -d ./.testrepository ] ; then testr init ; fi
testr run %{?_smp_mflags:--parallel %{_smp_flags}} #; RET=$? echo "Slowest Tests" ; testr slowest && exit $RET

%files
%defattr(-,root,root,-)
%doc ChangeLog README.rst LICENSE AUTHORS
%{_bindir}/dib-lint
%{_bindir}/element-info
%{_bindir}/*disk-image-create
%{_datadir}/%{name}
%{python_sitelib}/diskimage_builder/
%{python_sitelib}/diskimage_builder*.egg-info/

%changelog
* Thu Dec 22 2016 mchandras@suse.de
- Update to version 1.26.1
  * Generate ssh-hostkeys on boot for ironic agent
  * add option to configure cloud-init to allow password authentication
  * elements: Drop unneeded DIB_INIT_SYSTEM usage
  * Replace six.iteritems() with .items()
  * Catch errors in DIB_INIT_SYSTEM export
  * DIB element to support cinder local attach/detach functionality
  * elements: Drop executable bits from environment files
  * Update sysctl-write-value to do conflict checking
  * Put MKFS_OPTS after filesystem type
  * Make dib-python use the default python for distro
  * Don't set the executable bit on dhcp-interface@.service
  * Move pip-and-virtualenv source install to 10-
  * Add install-types as pip-and-virtualenv dep
  * Allow package-installs to parse DIB_PYTHON_VERSION
  * Fix pip-and-virtualenv to work with python3
  * elements: dib-python: Add python2 as the default version for openSUSE
  * Support sysv init system used by Debian Wheezy
  * Pip install as 10- incompatible with 05-heat-cfntools
  * Recreate initramfs within loopback image
  * Fix bootloader element on ppc
  * Add ubuntu-precise support to dib-python
  * FIx the DIB_CLOUD_INIT_ALLOW_SSH_PWAUTH variable name in README file
  * Switch to openSUSE Leap 42.2 release by default
  * Install dracut-generic-config package
  * Add output image format tgz support
  * Add squashfs output image format
  * set default DIB_PYTHON_VERSION=2 for rhel7
  * Set grub timeout default
  * Dont run with VIRTUAL_ENV set
* Mon Dec  5 2016 mchandras@suse.de
- Update to version 1.24.0
  * elements: pip-and-virtualenv: Add python-xml dependency
  * Trace package install in package-installs-v2
  * elements: zypper-minimal: Add ca-certificates-mozilla package
  * Improve checksum performance for images
  * Perform package install outside of debootstrap
  * Remove obsolete patches for the time being
  - 0001-lib-Drop-shebang-from-library-scripts.patch
  - 0002-elements-Drop-executable-bits-from-environment-files.patch
* Tue Oct 18 2016 mchandras@suse.de
- Use addFilter instead of setBadness in the rpmlintrc file.
* Mon Oct 17 2016 mchandras@suse.de
- Initial commit. Taken from the Cloud OBS project
  * diskimage-builder-rpmlintrc: Add rpmlint file to prevent build
    failures due to the 'wrong-script-interpreter' check. It's a
    spurious warning since the interpreter is only used within the
    generated image and it does not affect the host or the package
    itself.
  * 0001-lib-Drop-shebang-from-library-scripts.patch: Add patch to
    drop the shebang from the lib/* files which are meant to be
    sourced instead of executed (fixes: 'non-executable-script')
  * 0002-elements-Drop-executable-bits-from-environment-files.patch:
    Add patch to drop the executable bit from files which are meant to
    be sourced instead of executed. (fixes: 'script-without-shebang')
